@@ -50,10 +50,12 @@ __all__ = (
     "ApiAssociationTypeDef",
     "ApiCacheTypeDef",
     "ApiKeyTypeDef",
+    "AppSyncRuntimeTypeDef",
     "AssociateApiRequestRequestTypeDef",
     "ResponseMetadataTypeDef",
     "AwsIamConfigTypeDef",
     "CachingConfigTypeDef",
+    "CodeErrorLocationTypeDef",
     "CreateApiCacheRequestRequestTypeDef",
     "CreateApiKeyRequestRequestTypeDef",
     "ElasticsearchDataSourceConfigTypeDef",
@@ -109,6 +111,7 @@ __all__ = (
     "UpdateDomainNameRequestRequestTypeDef",
     "UpdateTypeRequestRequestTypeDef",
     "AdditionalAuthenticationProviderTypeDef",
+    "EvaluateCodeRequestRequestTypeDef",
     "AssociateApiResponseTypeDef",
     "CreateApiCacheResponseTypeDef",
     "CreateApiKeyResponseTypeDef",
@@ -122,6 +125,7 @@ __all__ = (
     "UpdateApiCacheResponseTypeDef",
     "UpdateApiKeyResponseTypeDef",
     "AuthorizationConfigTypeDef",
+    "CodeErrorTypeDef",
     "CreateDomainNameResponseTypeDef",
     "GetDomainNameResponseTypeDef",
     "ListDomainNamesResponseTypeDef",
@@ -145,6 +149,7 @@ __all__ = (
     "GraphqlApiTypeDef",
     "UpdateGraphqlApiRequestRequestTypeDef",
     "HttpDataSourceConfigTypeDef",
+    "EvaluateCodeErrorDetailTypeDef",
     "CreateFunctionRequestRequestTypeDef",
     "CreateResolverRequestRequestTypeDef",
     "FunctionConfigurationTypeDef",
@@ -158,6 +163,7 @@ __all__ = (
     "CreateDataSourceRequestRequestTypeDef",
     "DataSourceTypeDef",
     "UpdateDataSourceRequestRequestTypeDef",
+    "EvaluateCodeResponseTypeDef",
     "CreateFunctionResponseTypeDef",
     "GetFunctionResponseTypeDef",
     "ListFunctionsResponseTypeDef",
@@ -275,6 +281,14 @@ ApiKeyTypeDef = TypedDict(
     total=False,
 )
 
+AppSyncRuntimeTypeDef = TypedDict(
+    "AppSyncRuntimeTypeDef",
+    {
+        "name": Literal["APPSYNC_JS"],
+        "runtimeVersion": str,
+    },
+)
+
 AssociateApiRequestRequestTypeDef = TypedDict(
     "AssociateApiRequestRequestTypeDef",
     {
@@ -322,6 +336,16 @@ class CachingConfigTypeDef(_RequiredCachingConfigTypeDef, _OptionalCachingConfig
     pass
 
 
+CodeErrorLocationTypeDef = TypedDict(
+    "CodeErrorLocationTypeDef",
+    {
+        "line": int,
+        "column": int,
+        "span": int,
+    },
+    total=False,
+)
+
 _RequiredCreateApiCacheRequestRequestTypeDef = TypedDict(
     "_RequiredCreateApiCacheRequestRequestTypeDef",
     {
@@ -993,6 +1017,29 @@ AdditionalAuthenticationProviderTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredEvaluateCodeRequestRequestTypeDef = TypedDict(
+    "_RequiredEvaluateCodeRequestRequestTypeDef",
+    {
+        "runtime": AppSyncRuntimeTypeDef,
+        "code": str,
+        "context": str,
+    },
+)
+_OptionalEvaluateCodeRequestRequestTypeDef = TypedDict(
+    "_OptionalEvaluateCodeRequestRequestTypeDef",
+    {
+        "function": str,
+    },
+    total=False,
+)
+
+
+class EvaluateCodeRequestRequestTypeDef(
+    _RequiredEvaluateCodeRequestRequestTypeDef, _OptionalEvaluateCodeRequestRequestTypeDef
+):
+    pass
+
+
 AssociateApiResponseTypeDef = TypedDict(
     "AssociateApiResponseTypeDef",
     {
@@ -1112,6 +1159,16 @@ class AuthorizationConfigTypeDef(
     pass
 
 
+CodeErrorTypeDef = TypedDict(
+    "CodeErrorTypeDef",
+    {
+        "errorType": str,
+        "value": str,
+        "location": CodeErrorLocationTypeDef,
+    },
+    total=False,
+)
+
 CreateDomainNameResponseTypeDef = TypedDict(
     "CreateDomainNameResponseTypeDef",
     {
@@ -1207,6 +1264,7 @@ EvaluateMappingTemplateResponseTypeDef = TypedDict(
     {
         "evaluationResult": str,
         "error": ErrorDetailTypeDef,
+        "logs": List[str],
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -1458,13 +1516,21 @@ HttpDataSourceConfigTypeDef = TypedDict(
     total=False,
 )
 
+EvaluateCodeErrorDetailTypeDef = TypedDict(
+    "EvaluateCodeErrorDetailTypeDef",
+    {
+        "message": str,
+        "codeErrors": List[CodeErrorTypeDef],
+    },
+    total=False,
+)
+
 _RequiredCreateFunctionRequestRequestTypeDef = TypedDict(
     "_RequiredCreateFunctionRequestRequestTypeDef",
     {
         "apiId": str,
         "name": str,
         "dataSourceName": str,
-        "functionVersion": str,
     },
 )
 _OptionalCreateFunctionRequestRequestTypeDef = TypedDict(
@@ -1473,8 +1539,11 @@ _OptionalCreateFunctionRequestRequestTypeDef = TypedDict(
         "description": str,
         "requestMappingTemplate": str,
         "responseMappingTemplate": str,
+        "functionVersion": str,
         "syncConfig": SyncConfigTypeDef,
         "maxBatchSize": int,
+        "runtime": AppSyncRuntimeTypeDef,
+        "code": str,
     },
     total=False,
 )
@@ -1505,6 +1574,8 @@ _OptionalCreateResolverRequestRequestTypeDef = TypedDict(
         "syncConfig": SyncConfigTypeDef,
         "cachingConfig": CachingConfigTypeDef,
         "maxBatchSize": int,
+        "runtime": AppSyncRuntimeTypeDef,
+        "code": str,
     },
     total=False,
 )
@@ -1529,6 +1600,8 @@ FunctionConfigurationTypeDef = TypedDict(
         "functionVersion": str,
         "syncConfig": SyncConfigTypeDef,
         "maxBatchSize": int,
+        "runtime": AppSyncRuntimeTypeDef,
+        "code": str,
     },
     total=False,
 )
@@ -1547,6 +1620,8 @@ ResolverTypeDef = TypedDict(
         "syncConfig": SyncConfigTypeDef,
         "cachingConfig": CachingConfigTypeDef,
         "maxBatchSize": int,
+        "runtime": AppSyncRuntimeTypeDef,
+        "code": str,
     },
     total=False,
 )
@@ -1558,7 +1633,6 @@ _RequiredUpdateFunctionRequestRequestTypeDef = TypedDict(
         "name": str,
         "functionId": str,
         "dataSourceName": str,
-        "functionVersion": str,
     },
 )
 _OptionalUpdateFunctionRequestRequestTypeDef = TypedDict(
@@ -1567,8 +1641,11 @@ _OptionalUpdateFunctionRequestRequestTypeDef = TypedDict(
         "description": str,
         "requestMappingTemplate": str,
         "responseMappingTemplate": str,
+        "functionVersion": str,
         "syncConfig": SyncConfigTypeDef,
         "maxBatchSize": int,
+        "runtime": AppSyncRuntimeTypeDef,
+        "code": str,
     },
     total=False,
 )
@@ -1599,6 +1676,8 @@ _OptionalUpdateResolverRequestRequestTypeDef = TypedDict(
         "syncConfig": SyncConfigTypeDef,
         "cachingConfig": CachingConfigTypeDef,
         "maxBatchSize": int,
+        "runtime": AppSyncRuntimeTypeDef,
+        "code": str,
     },
     total=False,
 )
@@ -1721,6 +1800,16 @@ class UpdateDataSourceRequestRequestTypeDef(
     pass
 
 
+EvaluateCodeResponseTypeDef = TypedDict(
+    "EvaluateCodeResponseTypeDef",
+    {
+        "evaluationResult": str,
+        "error": EvaluateCodeErrorDetailTypeDef,
+        "logs": List[str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 CreateFunctionResponseTypeDef = TypedDict(
     "CreateFunctionResponseTypeDef",
     {
